@@ -9,12 +9,19 @@ from typing import Any, ByteString, Callable, Mapping, Optional, Sequence
 from typing import Tuple as Tup
 from typing import Type, TypeVar, Union
 
+import orjson
 import tomlkit
 
 PICKLE_PROTOCOL = 5
 T = TypeVar("T")
 
 
+def _json_encode_default(obj: Any) -> Any:
+    if isinstance(obj, NestedDotDict):
+        # noinspection PyProtectedMember
+        return dict(obj._x)
+
+
 class NestedDotDict(Mapping):
     """
     A thin wrapper around a nested dict to make getting values easier.
@@ -26,17 +33,37 @@ class NestedDotDict(Mapping):
 
     """
 
+    def to_json(self, indent: bool = False) -> str:
+        kwargs = dict(option=orjson.OPT_INDENT_2) if indent else {}
+        encoded = orjson.dumps(dict(self), default=_json_encode_default, **kwargs)
+        return encoded.decode(encoding="utf8")
+
     @classmethod
     def read_toml(cls, path: Union[PurePath, str]) -> NestedDotDict:
         return NestedDotDict(tomlkit.loads(Path(path).read_text(encoding="utf8")))
 
     @classmethod
     def read_json(cls, path: Union[PurePath, str]) -> NestedDotDict:
-        return NestedDotDict(json.loads(Path(path).read_text(encoding="utf8")))
+        """
+        Reads JSON from a file, into a NestedDotDict.
+        If the JSON data is a list type, converts into a dict with the key ``data``.
+        """
+        data = orjson.loads(Path(path).read_text(encoding="utf8"))
+        if isinstance(data, list):
+            data = {"data": data}
+        data.__class__ = cls
+        return data
 
     @classmethod
     def read_pickle(cls, path: Union[PurePath, str]) -> NestedDotDict:
-        return NestedDotDict(pickle.loads(Path(path).read_bytes()))
+        """
+
+        Note that this function has potential security concerns.
+        This is because it relies on the pickle module.
+        """
+        data = Path(path).read_bytes()
+        data = pickle.loads(data)  # nosec
+        return NestedDotDict(data)
 
     @classmethod
     def parse_toml(cls, data: str) -> NestedDotDict:
@@ -44,7 +71,15 @@ class NestedDotDict(Mapping):
 
     @classmethod
     def parse_json(cls, data: str) -> NestedDotDict:
-        return NestedDotDict(json.loads(data))
+        """
+        Parses JSON from a string, into a NestedDotDict.
+        If the JSON data is a list type, converts into a dict with the key ``data``.
+        """
+        data = json.loads(data)
+        if isinstance(data, list):
+            data = {"data": data}
+        data.__class__ = cls
+        return NestedDotDict(data)
 
     @classmethod
     def parse_pickle(cls, data: ByteString) -> NestedDotDict:
@@ -59,6 +94,8 @@ class NestedDotDict(Mapping):
         Raises:
             ValueError: If a key (in this dict or a sub-dict) is not a str or contains a dot
         """
+        if not (hasattr(x, "items") and hasattr(x, "keys") and hasattr(x, "values")):
+            raise TypeError(f"Type {type(x)} for value {x} appears not to be dict-like")
         bad = [k for k in x if not isinstance(k, str)]
         if len(bad) > 0:
             raise ValueError(f"Keys were not strings for these values: {bad}")
@@ -69,8 +106,9 @@ class NestedDotDict(Mapping):
         # Let's make sure this constructor gets called on subdicts:
         self.leaves()
 
-    def write_json(self, path: Union[PurePath, str]) -> None:
-        Path(path).write_text(json.dumps(self._x), encoding="utf8")
+    def write_json(self, path: Union[PurePath, str], indent: bool = False) -> None:
+        kwargs = dict(option=orjson.OPT_INDENT_2) if indent else {}
+        Path(path).write_bytes(orjson.dumps(dict(self), default=_json_encode_default, **kwargs))
 
     def write_pickle(self, path: Union[PurePath, str]) -> None:
         Path(path).write_bytes(pickle.dumps(self._x, protocol=PICKLE_PROTOCOL))
@@ -84,7 +122,8 @@ class NestedDotDict(Mapping):
         """
         mp = {}
         for key, value in self._x.items():
-            assert len(key) > 0
+            if len(key) == 0:
+                raise AssertionError(f"Key is empty (value=${value})")
             if isinstance(value, dict):
                 mp.update({key + "." + k: v for k, v in NestedDotDict(value).leaves().items()})
             else:
@@ -264,7 +303,12 @@ class NestedDotDict(Mapping):
         Returns:
             A multi-lined string
         """
-        return json.dumps(self.leaves(), sort_keys=True, indent=4, ensure_ascii=False,)
+        return json.dumps(
+            self.leaves(),
+            sort_keys=True,
+            indent=4,
+            ensure_ascii=False,
+        )
 
     def __len__(self) -> int:
         """
