@@ -2,13 +2,11 @@ from __future__ import annotations
 
 import datetime
 import logging
-import os
 from datetime import datetime
 from pathlib import Path
 from typing import Optional
 
 from pocketutils.core import PathLike
-from pocketutils.core.exceptions import DirDoesNotExistError
 
 
 class BasicFlexLogger:
