@@ -36,7 +36,10 @@ class CommonTools(BaseTools):
 
     @classmethod
     def try_none(
-        cls, function: Callable[[], T], fail_val: Optional[T] = None, exception=Exception,
+        cls,
+        function: Callable[[], T],
+        fail_val: Optional[T] = None,
+        exception=Exception,
     ) -> Optional[T]:
         """
         Returns the value of a function or None if it raised an exception.
@@ -46,6 +49,7 @@ class CommonTools(BaseTools):
             fail_val: Return this value
             exception: Restrict caught exceptions to subclasses of this type
         """
+        # noinspection PyBroadException
         try:
             return function()
         except exception:
@@ -74,9 +78,9 @@ class CommonTools(BaseTools):
         Returns ``dtype(x)`` if ``x`` is not None, or raises ``or_else``.
         """
         if or_else is None:
-            or_else = LookupError("Value is {}".format(x))
+            or_else = LookupError(f"Value is {x}")
         elif isinstance(or_else, type):
-            or_else = or_else("Value is {}".format(x))
+            or_else = or_else(f"Value is {x}")
         if cls.is_null(x):
             raise or_else
         return dtype(x)
@@ -100,12 +104,12 @@ class CommonTools(BaseTools):
             - None
             - NaN
         """
-        return (
-            x is None
-            or isinstance(x, np.float)
-            and np.isnan(x)
-            or (isinstance(x, float) and x == float("nan"))
-        )
+        try:
+            if np.isnan(x):
+                return True
+        except (ValueError, TypeError):
+            pass
+        return x is None or x == float("nan")
 
     @classmethod
     def is_empty(cls, x: Any) -> bool:
@@ -121,11 +125,14 @@ class CommonTools(BaseTools):
         """
         if isinstance(x, Iterator):
             raise RefusingRequestError("Do not call is_empty on an iterator.")
+        try:
+            if np.isnan(x):
+                return True
+        except (ValueError, TypeError):
+            pass
         return (
             x is None
-            or isinstance(x, np.float)
-            and np.isnan(x)
-            or (isinstance(x, float) and x == float("nan"))
+            or x == float("nan")
             or hasattr(x, "__len__")
             and len(x) == 0
             or hasattr(x, "__iter__")
@@ -140,13 +147,17 @@ class CommonTools(BaseTools):
             - np.is_nan(x)
             - x is something with 0 length
             - x is iterable and has 0 elements (will call ``__iter__``)
-            - a str(x) is 'nan', 'null', or 'none'; case-insensitive
-        In contrast to is_nan, also returns True if x==''.
+            - a str(x) is 'nan', 'n/a', 'null', or 'none'; case-insensitive
+
+        Things that are **NOT** probable nulls:
+            - "na"
+            - 0
+            - [None]
 
         Raises:
             TypeError If ``x`` is an Iterator. Calling this would empty the iterator, which is dangerous.
         """
-        return cls.is_empty(x) or str(x).lower() in ["nan", "null", "none"]
+        return cls.is_empty(x) or str(x).lower() in ["nan", "n/a", "null", "none"]
 
     @classmethod
     def unique(cls, sequence: Iterable[T]) -> Sequence[T]:
@@ -178,7 +189,6 @@ class CommonTools(BaseTools):
             - The attribute of the first element if ``attr`` is defined on an element
             - None if the the sequence is empty
             - None if the sequence has no attribute ``attr``
-
         """
         try:
             # note: calling iter on an iterator creates a view only
@@ -218,7 +228,7 @@ class CommonTools(BaseTools):
         for item in sequence:
             v = CommonTools.look(item, key_attr)
             if not skip_none and v is None:
-                raise KeyError("No {} in {}".format(key_attr, item))
+                raise KeyError(f"No {key_attr} in {item}")
             if v is not None:
                 dct[v].append(item)
         return dct
@@ -261,7 +271,28 @@ class CommonTools(BaseTools):
             return False
         if s.lower() == "true":
             return True
-        raise ValueError("{} is not true/false".format(s))
+        raise ValueError(f"{s} is not true/false")
+
+    @classmethod
+    def parse_bool_flex(cls, s: str) -> bool:
+        """
+        Parses a 'true'/'false'/'yes'/'no'/... string to a bool, ignoring case.
+
+        Allowed:
+            - "true", "t", "yes", "y", "1", "+"
+            - "false", "f", "no", "n", "0", "-"
+
+        Raises:
+            ValueError: If neither true nor false
+        """
+        mp = {
+            **{v: True for v in {"true", "t", "yes", "y", "1", "+"}},
+            **{v: False for v in {"false", "f", "no", "n", "0", "-"}},
+        }
+        v = mp.get(s.lower())
+        if v is None:
+            raise ValueError(f"{s.lower()} is not in {','.join(mp.keys())}")
+        return v
 
 
 __all__ = ["CommonTools"]
