@@ -27,7 +27,7 @@ from pocketutils.core.exceptions import (
     FileDoesNotExistError,
     ParsingError,
 )
-from pocketutils.core.hasher import *
+from pocketutils.core.hashers import *
 from pocketutils.core.input_output import OpenMode, PathLike, Writeable
 from pocketutils.core.web_resource import *
 from pocketutils.tools.base_tools import BaseTools
@@ -48,24 +48,43 @@ try:
 except ImportError:
     # zero them all out
     jsonpickle, jsonpickle_numpy, jsonpickle_pandas = None, None, None
-    logger.error("Could not import jsonpickle")
+    logger.debug("Could not import jsonpickle", exc_info=True)
+
+
+try:
+    from defusedxml import ElementTree
+except ImportError:
+    logger.warning("Could not import defusedxml; falling back to xml")
+    from xml.etree import ElementTree
 
 
 class FilesysTools(BaseTools):
+    """
+    Tools for file/directory creation, etc.
+
+    Security concerns
+    -----------------
+
+    Please note that several of these functions expose security concerns.
+    In particular, ``pkl``, ``unpkl``, and any others that involve pickle or its derivatives.
+    """
+
     @classmethod
     def pkl(cls, stuff: Any, path: PathLike) -> None:
         """Save to a file with dill."""
-        Path(path).write_bytes(dill.dumps(stuff, protocol=5))
+        data = dill.dumps(stuff, protocol=5)  # nosec
+        Path(path).write_bytes(data)
 
     @classmethod
     def unpkl(cls, path: PathLike):
         """Load a file with dill."""
         # ignore encoding param, which is only useful for unpickling Python 2-generated
-        return dill.loads(Path(path).read_bytes())
+        data = Path(path).read_bytes()
+        return dill.loads(data)  # nosec
 
     @classmethod
-    def new_hasher(cls, algorithm: str = "sha1"):
-        return FileHasher(algorithm)
+    def new_hasher(cls, algorithm: str = "sha1") -> Hasher:
+        return Hasher(algorithm)
 
     @classmethod
     def new_webresource(
@@ -116,31 +135,31 @@ class FilesysTools(BaseTools):
             IOError: If it can't delete
         """
         # we need this because of Windows
-        path = str(path)
-        logger.debug("Permanently deleting {} ...".format(path))
+        path = Path(path)
+        logger.debug(f"Permanently deleting {path} ...")
         chmod_err = None
         try:
-            os.chmod(path, stat.S_IRWXU)
+            os.chmod(str(path), stat.S_IRWXU)
         except Exception as e:
             chmod_err = e
         # another reason for returning exception:
         # We don't want to interrupt the current line being printed like in slow_delete
-        if os.path.isdir(path):
-            shutil.rmtree(path, ignore_errors=True)  # ignore_errors because of Windows
+        if path.is_dir():
+            shutil.rmtree(str(path), ignore_errors=True)  # ignore_errors because of Windows
             try:
-                os.remove(path)  # again, because of Windows
+                path.unlink(missing_ok=True)  # again, because of Windows
             except IOError:
                 pass  # almost definitely because it doesn't exist
         else:
-            os.remove(path)
-        logger.debug("Permanently deleted {}".format(path))
+            path.unlink(missing_ok=True)
+        logger.debug(f"Permanently deleted {path}")
         return chmod_err
 
     @classmethod
     def trash(cls, path: PathLike, trash_dir: PathLike = Path):
-        logger.debug("Trashing {} to {} ...".format(path, trash_dir))
+        logger.debug(f"Trashing {path} to {trash_dir} ...")
         shutil.move(str(path), str(trash_dir))
-        logger.debug("Trashed {} to {}".format(path, trash_dir))
+        logger.debug(f"Trashed {path} to {trash_dir}")
 
     @classmethod
     def try_cleanup(cls, path: Path) -> None:
@@ -148,11 +167,10 @@ class FilesysTools(BaseTools):
         Try to delete a file (probably temp file), if it exists, and log any PermissionError.
         """
         path = Path(path)
-        if path.exists():
-            try:
-                path.unlink()
-            except PermissionError:
-                logger.error("Permission error preventing deleting {}".format(path))
+        try:
+            path.unlink(missing_ok=True)
+        except PermissionError:
+            logger.error(f"Permission error preventing deleting {path}")
 
     @classmethod
     def read_lines_file(cls, path: PathLike, ignore_comments: bool = False) -> Sequence[str]:
@@ -187,11 +205,11 @@ class FilesysTools(BaseTools):
                 if len(line) == 0 or line.startswith("#"):
                     continue
                 if line.count("=") != 1:
-                    raise ParsingError("Bad line {} in {}".format(i, path))
+                    raise ParsingError(f"Bad line {i} in {path}")
                 k, v = line.split("=")
                 k, v = k.strip(), v.strip()
                 if k in dct:
-                    raise AlreadyUsedError("Duplicate property {} (line {})".format(k, i), key=k)
+                    raise AlreadyUsedError(f"Duplicate property {k} (line {i})", key=k)
                 dct[k] = v
         return dct
 
@@ -200,7 +218,7 @@ class FilesysTools(BaseTools):
         cls, properties: Mapping[Any, Any], path: Union[str, PurePath], mode: str = "o"
     ):
         if not OpenMode(mode).write:
-            raise ContradictoryRequestError("Cannot write text to {} in mode {}".format(path, mode))
+            raise ContradictoryRequestError(f"Cannot write text to {path} in mode {mode}")
         with FilesysTools.open_file(path, mode) as f:
             bads = []
             for k, v in properties.items():
@@ -215,7 +233,7 @@ class FilesysTools(BaseTools):
             if 0 < len(bads) <= 10:
                 logger.warning(
                     "At least one properties entry contains an equals sign or newline (\\n)."
-                    "These were escaped: {}".format(", ".join(bads))
+                    f"These were escaped: {', '.join(bads)}"
                 )
             elif len(bads) > 0:
                 logger.warning(
@@ -308,11 +326,9 @@ class FilesysTools(BaseTools):
         elif ext == "strings":
             return load_list(str)
         elif ext == "xml":
-            from xml.etree import ElementTree
-
             ElementTree.parse(path).getroot()
         else:
-            raise TypeError("Did not recognize resource file type for file {}".format(path))
+            raise TypeError(f"Did not recognize resource file type for file {path}")
 
     @classmethod
     def read_bytes(cls, path: PathLike) -> bytes:
@@ -325,16 +341,14 @@ class FilesysTools(BaseTools):
     @classmethod
     def write_bytes(cls, data: Any, path: PathLike, mode: str = "wb") -> None:
         if not OpenMode(mode).write or not OpenMode(mode).binary:
-            raise ContradictoryRequestError(
-                "Cannot write bytes to {} in mode {}".format(path, mode)
-            )
+            raise ContradictoryRequestError(f"Cannot write bytes to {path} in mode {mode}")
         with cls.open_file(path, mode) as f:
             f.write(data)
 
     @classmethod
     def write_text(cls, data: Any, path: PathLike, mode: str = "w"):
         if not OpenMode(mode).write or OpenMode(mode).binary:
-            raise ContradictoryRequestError("Cannot write text to {} in mode {}".format(path, mode))
+            raise ContradictoryRequestError(f"Cannot write text to {path} in mode {mode}")
         with cls.open_file(path, mode) as f:
             f.write(str(data))
 
@@ -351,7 +365,7 @@ class FilesysTools(BaseTools):
         path = Path(path)
         mode = OpenMode(mode)
         if mode.write and mode.safe and path.exists():
-            raise FileDoesNotExistError("Path {} already exists".format(path))
+            raise FileDoesNotExistError(f"Path {path} already exists")
         if not mode.read:
             PathTools.prep_file(path, exist_ok=mode.overwrite or mode.append)
         if mode.gzipped:
@@ -378,7 +392,7 @@ class FilesysTools(BaseTools):
         path = Path(path)
         mode = OpenMode(mode)
         if not mode.overwrite or mode.binary:
-            raise ContradictoryRequestError("Wrong mode for writing a text file: {}".format(mode))
+            raise ContradictoryRequestError(f"Wrong mode for writing a text file: {mode}")
         if not cls.is_true_iterable(iterable):
             raise TypeError("Not a true iterable")  # TODO include iterable if small
         PathTools.prep_file(path, exist_ok=mode.overwrite or mode.append)
@@ -424,7 +438,7 @@ class FilesysTools(BaseTools):
         If `path` is None, will use `tempfile.mktemp`.
         """
         if path is None:
-            path = tempfile.mktemp()
+            _, path = tempfile.mkstemp()
         try:
             yield Path(path, **kwargs)
         finally:
