@@ -1,7 +1,7 @@
 import json
 import re
 from copy import copy
-from typing import Any, Iterable, Mapping, Optional, Sequence, Tuple, TypeVar, Union
+from typing import Any, Iterable, Mapping, Optional, Sequence, Tuple, TypeVar, Union, Callable
 
 import numpy as np
 
@@ -23,13 +23,80 @@ class StringTools(BaseTools):
         # return Pretty.condensed(dct)
         return cls.retab(
             json.dumps(
-                dct, default=JsonEncoder().default, sort_keys=True, indent=1, ensure_ascii=False,
+                dct,
+                default=JsonEncoder().default,
+                sort_keys=True,
+                indent=1,
+                ensure_ascii=False,
             ),
             1,
         )
 
+    @classmethod
+    def extract_group_1(
+        cls, pattern: Union[str, re.Pattern], value: Optional[str], ignore_null: bool = False
+    ) -> Optional[str]:
+        """
+        Performs a ``fullmatch`` on a target string and returns capture group 1, or None if there was no match.
+
+        Args:
+            pattern: Regex pattern
+            value: The target string
+            ignore_null: If True, returns None if ``value`` is None; otherwise raises a ValueError if ``value`` is None
+                         (Useful for *map*-like operations.)
+
+        Returns The first capture group, or None
+        """
+        pattern = pattern if isinstance(pattern, re.Pattern) else re.compile(pattern)
+        if pattern.groups != 1:
+            raise ValueError(f"Pattern {pattern} has {pattern.groups} groups, not 1")
+        if value is None and ignore_null:
+            return None
+        match = pattern.fullmatch(value)
+        if match is None:
+            return None
+        return match.group(1)
+
+    @classmethod
+    def roman_to_arabic(
+        cls, roman: str, min_val: Optional[int] = None, max_val: Optional[int] = None
+    ) -> int:
+        """
+        Converts roman numerals to an integer.
+
+        Args:
+            roman: A string like "MCIV"
+            min_val: Raise a ValueError if the parsed value is less than this
+            max_val: Raise a ValueError if the parsed value is more than this
+
+        Returns:
+            The arabic numeral as a Python int
+        """
+        # this order is IMPORTANT!
+        mp = dict(
+            IV=4, IX=9, XL=40, XC=90, CD=400, CM=900, I=1, V=5, X=10, L=50, C=100, D=500, M=1000
+        )
+        for k, v in mp.items():
+            roman = roman.replace(k, str(v))
+        # it'll just error if it's empty
+        try:
+            value = sum((int(num) for num in roman))
+        except (ValueError, StopIteration):
+            raise ValueError(f"Cannot parse roman numerals '{roman}'")
+        if min_val is not None and value < min_val or min_val is not None and roman > max_val:
+            raise ValueError(f"Value {roman} (int={value}) is out of range ({min_val}, {max_val})")
+        return value
+
     @classmethod
     def retab(cls, s: str, nspaces: int) -> str:
+        """
+        Converts indentation with spaces to tab indentation.
+
+        Args:
+            s: The string to convert
+            nspaces: A tab is this number of spaces
+        """
+
         def fix(m):
             n = len(m.group(1)) // nspaces
             return "\t" * n + " " * (len(m.group(1)) % nspaces)
@@ -54,6 +121,22 @@ class StringTools(BaseTools):
         else:
             return t
 
+    @classmethod
+    def tabs_to_list(cls, s: str) -> Sequence[str]:
+        """
+        Splits by tabs, but preserving quoted tabs, stripping quotes.
+        """
+        pat = re.compile(r"""((?:[^\t"']|"[^"]*"|'[^']*')+)""")
+        # Don't strip double 2x quotes: ex ""55"" should be "55", not 55
+        def strip(i: str) -> str:
+            if i.endswith('"') or i.endswith("'"):
+                i = i[:-1]
+            if i.startswith('"') or i.startswith("'"):
+                i = i[1:]
+            return i.strip()
+
+        return [strip(i) for i in pat.findall(s)]
+
     @classmethod
     def truncate(cls, s: Optional[str], n: int, always_dots: bool = False) -> Optional[str]:
         """
@@ -79,45 +162,38 @@ class StringTools(BaseTools):
             return s[:nx] + "…"
         return s
 
-    @classmethod
-    def tabs_to_list(cls, s: str) -> Sequence[str]:
-        """
-        Splits by tabs, but preserving quoted tabs, stripping quotes.
-        """
-        pat = re.compile(r"""((?:[^\t"']|"[^"]*"|'[^']*')+)""")
-        # Don't strip double 2x quotes: ex ""55"" should be "55", not 55
-        def strip(i: str) -> str:
-            if i.endswith('"') or i.endswith("'"):
-                i = i[:-1]
-            if i.startswith('"') or i.startswith("'"):
-                i = i[1:]
-            return i.strip()
-
-        return [strip(i) for i in pat.findall(s)]
-
     # these are provided to avoid having to call with labdas or functools.partial
     @classmethod
-    def truncate60(cls, s):
+    def truncator(cls, n: int = 40, always_dots: bool = False) -> Callable[[str], str]:
+        # pretty much functools.partial
+        def trunc(s: str) -> str:
+            return cls.truncate(s, n, always_dots)
+
+        trunc.__name__ = f"truncate({n},{'…' if always_dots else ''})"
+        return trunc
+
+    @classmethod
+    def truncate60(cls, s: str) -> str:
         return StringTools.truncate(s, 60)
 
     @classmethod
-    def truncate40(cls, s):
+    def truncate40(cls, s: str) -> str:
         return StringTools.truncate(s, 64)
 
     @classmethod
-    def truncate30(cls, s):
+    def truncate30(cls, s: str) -> str:
         return StringTools.truncate(s, 30)
 
     @classmethod
-    def truncate20(cls, s):
+    def truncate20(cls, s: str) -> str:
         return StringTools.truncate(s, 20)
 
     @classmethod
-    def truncate10(cls, s):
+    def truncate10(cls, s: str) -> str:
         return StringTools.truncate(s, 10)
 
     @classmethod
-    def truncate10_nodots(cls, s):
+    def truncate10_nodots(cls, s: str) -> str:
         return StringTools.truncate(s, 10, False)
 
     @classmethod
@@ -137,7 +213,8 @@ class StringTools(BaseTools):
         Strips the full string `pre` from the start of `str`.
         See ``Tools.strip_off`` for more info.
         """
-        assert isinstance(pre, str), "{} is not a string".format(pre)
+        if not isinstance(pre, str):
+            raise TypeError(f"{pre} is not a string")
         if s.startswith(pre):
             s = s[len(pre) :]
         return s
@@ -148,7 +225,8 @@ class StringTools(BaseTools):
         Strips the full string `suf` from the end of `str`.
         See `Tools.strip_off` for more info.
         """
-        assert isinstance(suf, str), "{} is not a string".format(suf)
+        if not isinstance(suf, str):
+            raise TypeError(f"{suf} is not a string")
         if s.endswith(suf):
             s = s[: -len(suf)]
         return s
@@ -171,7 +249,10 @@ class StringTools(BaseTools):
 
     @classmethod
     def strip_any_ends(
-        cls, s: str, prefixes: Union[str, Sequence[str]], suffixes: Union[str, Sequence[str]],
+        cls,
+        s: str,
+        prefixes: Union[str, Sequence[str]],
+        suffixes: Union[str, Sequence[str]],
     ) -> str:
         """
         Flexible variant that strips any number of prefixes and any number of suffixes.
@@ -270,10 +351,7 @@ class StringTools(BaseTools):
         Also see ``strip_brackets``
         """
         if any([a for a in pieces if len(a) != 2]):
-            raise ValueError(
-                "strip_paired requires each item in `pieces` be a string of length 2: (stard, end);"
-                "got {}".format(pieces)
-            )
+            raise ValueError(f"Each item must be a string of length 2: (stard, end); got {pieces}")
         text = str(text)
         while len(text) > 0:
             yes = False
@@ -360,7 +438,9 @@ class StringTools(BaseTools):
         # TODO this seems absurdly long for what it does
         if n_sigfigs is None or n_sigfigs < 1:
             raise OutOfRangeError(
-                "Sigfigs of {} is nonpositive".format(n_sigfigs), value=n_sigfigs, minimum=1,
+                f"Sigfigs of {n_sigfigs} is nonpositive",
+                value=n_sigfigs,
+                minimum=1,
             )
         # first, handle NaN and infinities
         if np.isneginf(v):
@@ -486,7 +566,8 @@ class StringTools(BaseTools):
         # If we just sort from longest to shortest, we can't replace substrings by accident
         # For example we'll replace 'beta' before 'eta', so '1-beta' won't become '1-bη'
         greek = sorted(
-            [(v, k) for k, v in StringTools._greek_alphabet.items()], key=lambda t: -len(t[1]),
+            [(v, k) for k, v in StringTools._greek_alphabet.items()],
+            key=lambda t: -len(t[1]),
         )
         for k, v in greek:
             if k[0].isupper() and lowercase:
@@ -529,7 +610,12 @@ class StringTools(BaseTools):
 
     @classmethod
     def join_kv(
-        cls, seq: Mapping[T, V], sep: str = "\t", eq: str = "=", prefix: str = "", suffix: str = "",
+        cls,
+        seq: Mapping[T, V],
+        sep: str = "\t",
+        eq: str = "=",
+        prefix: str = "",
+        suffix: str = "",
     ) -> str:
         """
         Joins dict elements into a str like 'a=1, b=2, c=3`.
@@ -537,6 +623,7 @@ class StringTools(BaseTools):
 
         Args:
             seq: Dict-like, with ``items()``
+            sep: Delimiter
             eq: Separates a key with its value
             prefix: Prepend before every key
             suffix: Append after every value
