@@ -59,10 +59,14 @@ class UnitTools(BaseTools):
         hours = int((ms / (1000 * 60 * 60)) % 24)
         days = int(ms / (1000 * 60 * 60 * 24))
         if ms < 1000:
-            s = "{}{}ms".format(space, ms)
+            s = f"{space}{ms}ms"
         elif days > 1:
             s = "{}{}d:{}:{}:{}".format(
-                days, space, str(hours).zfill(2), str(minutes).zfill(2), str(seconds).zfill(2),
+                days,
+                space,
+                str(hours).zfill(2),
+                str(minutes).zfill(2),
+                str(seconds).zfill(2),
             )
         elif hours > 1:
             s = "{}:{}:{}".format(str(hours).zfill(2), str(minutes).zfill(2), str(seconds).zfill(2))
@@ -79,7 +83,7 @@ class UnitTools(BaseTools):
         return nicesize(n_bytes)
 
     @classmethod
-    def round_to_sigfigs(cls, num: SupportsFloat, sig_figs: int) -> int:
+    def round_to_sigfigs(cls, num: SupportsFloat, sig_figs: int) -> float:
         """
         Round to specified number of sigfigs.
 
@@ -91,38 +95,39 @@ class UnitTools(BaseTools):
             A Python integer
         """
         if sig_figs < 0:
-            raise OutOfRangeError("sig_figs {} is negative".format(sig_figs), minimum=0)
+            raise OutOfRangeError(f"sig_figs {sig_figs} is negative", minimum=0)
         num = float(num)
         if num != 0:
-            return round(num, -int(math.floor(math.log10(abs(num))) - (sig_figs - 1)))
+            digits = -int(math.floor(math.log10(abs(num))) - (sig_figs - 1))
+            return round(num, digits)
         else:
             return 0  # can't take the log of 0
 
     @classmethod
-    def nice_dose(
+    def format_micromolar(
         cls,
-        micromolar_dose: float,
+        micromolar: float,
         n_sigfigs: Optional[int] = 5,
         adjust_units: bool = True,
         use_sigfigs: bool = True,
         space: str = "",
     ) -> str:
         """
-        Returns a dose with units, with the units scaled as needed.
+        Returns a concentration with units, with the units scaled as needed.
         Can handle millimolar, micromolar, nanomolar, and picomolar.
 
         Args:
-            use_sigfigs: If True, rounds to a number of significant figures; otherwise round to decimal places
-            micromolar_dose: The dose in micromolar
+            micromolar: Value
             n_sigfigs: For rounding; no rounding if None
             adjust_units: If False, will always use micromolar
+            use_sigfigs: If True, rounds to a number of significant figures; otherwise round to decimal places
             space: Space char between digits and units;
-        good choices are empty, ASCII space, Chars.narrownbsp, Chars.thinspace, and Chars.nbsp.
+                   good choices are empty, ASCII space, Chars.narrownbsp, Chars.thinspace, and Chars.nbsp.
 
         Returns:
-            The dose with a suffix of µM, mM, nM, or mM
+            The concentration with a suffix of µM, mM, nM, or mM
         """
-        d = micromolar_dose
+        d = micromolar
         m = abs(d)
         unit = "µM"
         if adjust_units:
@@ -155,7 +160,14 @@ class UnitTools(BaseTools):
     @classmethod
     def split_drug_dose(cls, text: str) -> Tuple[str, Optional[float]]:
         """
-        Splits a name into a drug/dose pair, falling back with the full name.
+        Deprecated; see ``split_micromolar``.
+        """
+        return cls.split_species_micromolar(text)
+
+    @classmethod
+    def split_species_micromolar(cls, text: str) -> Tuple[str, Optional[float]]:
+        """
+        Splits a name into a chemical/concentration pair, falling back with the full name.
         Ex: "abc 3.5uM" → (abc, 3.5)
         Ex: "abc 3.5 µM" → (abc, 3.5)
         Ex: "abc (3.5mM)" → (abc, 3500.0)
@@ -172,9 +184,7 @@ class UnitTools(BaseTools):
         )
         match = pat.fullmatch(text)
         if match is None:
-            raise StringPatternError(
-                "The text {} couldn't be parsed".format(text), value=text, pattern=pat
-            )
+            raise StringPatternError(f"Text {text} couldn't be parsed", value=text, pattern=pat)
         if match.group(2) is None:
             return text.strip(), None
         else:
@@ -184,6 +194,13 @@ class UnitTools(BaseTools):
 
     @classmethod
     def extract_dose(cls, text: str) -> Optional[float]:
+        """
+        Deprecated; see ``extract_micromolar``.
+        """
+        return cls.extract_micromolar(text)
+
+    @classmethod
+    def extract_micromolar(cls, text: str) -> Optional[float]:
         """
         Returns what looks like a concentration with units. Accepts one of: mM, µM, uM, nM, pM.
         Searches pretty flexibly.
@@ -204,20 +221,30 @@ class UnitTools(BaseTools):
         if len(matches) == 1:
             return next(iter(matches))
         elif len(matches) > 1:
-            logger.warning(
-                "Found {} potential doses: {} . Returning None.".format(len(matches), matches)
-            )
+            logger.warning(f"Found {len(matches)} potential doses: {matches} . Returning None.")
         return None
 
     @classmethod
     def dose_to_micromolar(cls, digits: Union[str, float], units: str) -> float:
         """
-        Ex: dose_to_micromolar(53, 'nM')  # returns 0.053
+        Deprecated; see ``concentration_to_micromolar``.
         """
-        return (
-            float(digits)
-            * {"M": 1e6, "mM": 1e3, "µM": 1, "uM": 1, "nM": 1e-3, "pM": 1e-6, "fM": 1e-9,}[units]
-        )
+        return cls.concentration_to_micromolar(digits, units)
+
+    @classmethod
+    def concentration_to_micromolar(cls, digits: Union[str, float], units: str) -> float:
+        """
+        Ex: concentration_to_micromolar(53, 'nM')  # returns 0.053
+        """
+        return float(digits) * {
+            "M": 1e6,
+            "mM": 1e3,
+            "µM": 1,
+            "uM": 1,
+            "nM": 1e-3,
+            "pM": 1e-6,
+            "fM": 1e-9,
+        }[units]
 
 
 __all__ = ["UnitTools"]
